@@ -397,6 +397,21 @@ class AsyncSubscriber(PatchworkSubscriber):
         """
         raise NotImplementedError()
 
+    async def rollback(self, task: Task, *, timeout: float = None):
+        """
+        Rollback given task returned by get() method.
+        Meaning of "rollback" depends on queue backend, but after this operation exactly the same task should
+        be delivered again. Use this with caution as exactly the same is strict, so your code will receive
+        the same bytes again and again. Make sure that it doesn't lead to infinite loop.
+
+        For retries, it's recommended to store some retries counter in task meta, send retry task explicitly
+        with bumped counter and commit the failed one.
+        :param task:
+        :param timeout:
+        :return:
+        """
+        raise NotImplementedError()
+
     async def _fetch_one(self, *, timeout: float = None) -> Tuple[bytes, Mapping]:
         """
         Fetch one incoming message from the queue.
