@@ -93,7 +93,7 @@ async def test_shared_default_queue():
         payload, meta = await client_2._fetch_one()
 
     assert payload == b'payload'
-    assert meta == {}
+    assert meta == {'queue_name': 'test'}
 
 
 @pytest.mark.asyncio
@@ -103,7 +103,7 @@ async def test_fetch_one(subscriber, broker):
     payload, meta = await subscriber._fetch_one()
 
     assert payload == b'payload'
-    assert meta == {}
+    assert meta == {'queue_name': 'test'}
 
 
 @pytest.mark.asyncio
@@ -144,4 +144,4 @@ async def test_subscribe_on_missing():
         payload, meta = await client_2._fetch_one()
 
     assert payload == b'payload'
-    assert meta == {}
+    assert meta == {'queue_name': 'test-missing'}
